@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Test::LWP::UserAgent; # git description: v0.029-15-g64c59da
+package Test::LWP::UserAgent; # git description: v0.030-12-g8dd6557
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A LWP::UserAgent suitable for simulating and testing network calls
 # KEYWORDS: testing useragent networking mock server client
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 
 use parent 'LWP::UserAgent';
 use Scalar::Util qw(blessed reftype);
@@ -339,7 +339,7 @@ sub __isa_coderef
 
 sub __is_regexp
 {
-    re->can('is_regexp') ? re::is_regexp(shift) : ref(shift) eq 'Regexp';
+    re->can('is_regexp') ? re::is_regexp($_[0]) : ref($_[0]) eq 'Regexp';
 }
 
 # returns true if is expected type for all response mappings,
@@ -366,7 +366,7 @@ Test::LWP::UserAgent - A LWP::UserAgent suitable for simulating and testing netw
 
 =head1 VERSION
 
-version 0.030
+version 0.031
 
 =head1 SYNOPSIS
 
@@ -742,14 +742,6 @@ throughout. It provides a method (C<last_http_request_sent>) to access the last
 L<HTTP::Request>, for testing things like the URI and headers that your code
 sent to L<LWP::UserAgent>.
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Test-LWP-UserAgent>
-(or L<bug-Test-LWP-UserAgent@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 ACKNOWLEDGEMENTS
 
 =for stopwords AirG Yury Zavarin mst
@@ -796,6 +788,19 @@ L<Plack::Test>, L<Plack::Test::ExternalServer>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Test-LWP-UserAgent>
+(or L<bug-Test-LWP-UserAgent@rt.cpan.org|mailto:bug-Test-LWP-UserAgent@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/perl-qa.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#perl> on C<irc.perl.org>|irc://irc.perl.org/#perl-qa>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
